#[repr(transparent)]pub struct CopyableRow {
inner: TypedObjectRef<CopyableRow, <CopyableRow as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
An AdwActionRow with a button to copy the title or subtitle.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<CopyableRow, <CopyableRow as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl CopyableRow
impl CopyableRow
The tooltip text of the copy button.
The tooltip text of the copy button.
Sourcepub fn toast_text(&self) -> <RefCell<Option<String>> as Property>::Value
pub fn toast_text(&self) -> <RefCell<Option<String>> as Property>::Value
The text to show in a toast when the copy button is activated.
No toast is shown if this is None.
Sourcepub fn set_toast_text<'a>(
&self,
value: Option<impl Borrow<<<RefCell<Option<String>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_toast_text<'a>( &self, value: Option<impl Borrow<<<RefCell<Option<String>> as Property>::Value as HasParamSpec>::SetValue>>, )
The text to show in a toast when the copy button is activated.
No toast is shown if this is None.
Sourcepub fn main_title(&self) -> <Cell<ActionRowMainTitle> as Property>::Value
pub fn main_title(&self) -> <Cell<ActionRowMainTitle> as Property>::Value
The main title of this row.
This is used to decide the field to copy when the button is
activated. Also, if the subtitle is the main title, the property
CSS class is added.
Sourcepub fn set_main_title<'a>(
&self,
value: impl Borrow<<<Cell<ActionRowMainTitle> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_main_title<'a>( &self, value: impl Borrow<<<Cell<ActionRowMainTitle> as Property>::Value as HasParamSpec>::SetValue>, )
The main title of this row.
This is used to decide the field to copy when the button is
activated. Also, if the subtitle is the main title, the property
CSS class is added.
Sourcepub fn extra_suffix(&self) -> <PhantomData<Option<Widget>> as Property>::Value
pub fn extra_suffix(&self) -> <PhantomData<Option<Widget>> as Property>::Value
The extra suffix widget of this row.
The widget is placed before the remove button.
Sourcepub fn set_extra_suffix<'a>(
&self,
value: Option<impl Borrow<<<PhantomData<Option<Widget>> as Property>::Value as HasParamSpec>::SetValue>>,
)
pub fn set_extra_suffix<'a>( &self, value: Option<impl Borrow<<<PhantomData<Option<Widget>> as Property>::Value as HasParamSpec>::SetValue>>, )
The extra suffix widget of this row.
The widget is placed before the remove button.
Listen for notifications of a change in the copy-button-tooltip-text property
Sourcepub fn connect_toast_text_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_toast_text_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the toast-text property
Sourcepub fn connect_main_title_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_main_title_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the main-title property
Sourcepub fn connect_extra_suffix_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_extra_suffix_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the extra-suffix property
Notify listeners of a change in the copy-button-tooltip-text property
Sourcepub fn notify_toast_text(&self)
pub fn notify_toast_text(&self)
Notify listeners of a change in the toast-text property
Sourcepub fn notify_main_title(&self)
pub fn notify_main_title(&self)
Notify listeners of a change in the main-title property
Sourcepub fn notify_extra_suffix(&self)
pub fn notify_extra_suffix(&self)
Notify listeners of a change in the extra-suffix property
Sourceimpl CopyableRow
impl CopyableRow